==> gnuradio-examples-0.3.tar.gz: gnuradio-examples-0.3/python/audio/mono_tone.py <==
#!/usr/bin/env python
#
# Copyright 2004 Free Software Foundation, Inc.
# 
# This file is part of GNU Radio
# 
# GNU Radio is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
# 
# GNU Radio is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with GNU Radio; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
# 

from gnuradio import gr
from gnuradio import audio
from optparse import OptionParser


def build_graph (dev):
    sampling_freq = 48000
    ampl = 0.1

    fg = gr.flow_graph ()
    src0 = gr.sig_source_f (sampling_freq, gr.GR_SIN_WAVE, 350, ampl)
    dst = audio.sink (sampling_freq, dev)
    fg.connect (src0, (dst, 0))

    return fg

if __name__ == '__main__':
    parser = OptionParser ()
    parser.add_option ("-d", "--device", type="string", default="hw:0,0",
                        help="pcm device name.  E.g., hw:0,0")
    (options, args) = parser.parse_args ()
        
    fg = build_graph (options.device)
    fg.start ()
    raw_input ('Press Enter to quit: ')
    fg.stop ()

==> gnuradio-examples-0.4.tar.gz: gnuradio-examples-0.4/python/audio/mono_tone.py <==
#!/usr/bin/env python
#
# Copyright 2004 Free Software Foundation, Inc.
# 
# This file is part of GNU Radio
# 
# GNU Radio is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
# 
# GNU Radio is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with GNU Radio; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
# 

from gnuradio import gr
from gnuradio import audio
from optparse import OptionParser


def build_graph (dev):
    sampling_freq = 48000
    ampl = 0.1

    fg = gr.flow_graph ()
    src0 = gr.sig_source_f (sampling_freq, gr.GR_SIN_WAVE, 350, ampl)
    dst = audio.sink (sampling_freq, dev)
    fg.connect (src0, (dst, 0))

    return fg

if __name__ == '__main__':
    parser = OptionParser ()
    parser.add_option ("-d", "--device", type="string", default="",
                        help="pcm device name.  E.g., hw:0,0 or /dev/dsp")
    (options, args) = parser.parse_args ()
        
    fg = build_graph (options.device)
    fg.start ()
    raw_input ('Press Enter to quit: ')
    fg.stop ()
